@@ -5,9 +5,11 @@ dataverse_id <- function(x, ...) {
 dataverse_id.default <- function(x, ...) {
   x
 }
+#' @export
 dataverse_id.character <- function(x, ...) {
   get_dataverse(x, ..., check = FALSE)$id
 }
+#' @export
 dataverse_id.dataverse <- function(x, ...) {
   x$id
 }
@@ -16,18 +18,25 @@ dataverse_id.dataverse <- function(x, ...) {
 dataset_id <- function(x, ...) {
   UseMethod("dataset_id", x)
 }
+#' @export
 dataset_id.default <- function(x, ...) {
   x
 }
+#' @export
 dataset_id.character <- function(x, key = Sys.getenv("DATAVERSE_KEY"), server = Sys.getenv("DATAVERSE_SERVER"), ...) {
   x <- prepend_doi(x)
   u <- paste0(api_url(server), "datasets/:persistentId?persistentId=", x)
-  r <- tryCatch(httr::GET(u, httr::add_headers("X-Dataverse-key" = key), ...),
-                error = function(e) {
-                  stop("Could not retrieve Dataset ID from persistent identifier!")
-                })
-  jsonlite::fromJSON(httr::content(r, as = "text", encoding = "UTF-8"))[["data"]][["id"]]
+  r <- tryCatch({
+    api_get(u, ..., key = key)
+  }, error = function(e) {
+    stop(
+      "Could not retrieve Dataset ID from persistent identifier! ",
+      conditionMessage(e)
+    )
+  })
+  jsonlite::fromJSON(r)[["data"]][["id"]]
 }
+#' @export
 dataset_id.dataverse_dataset <- function(x, ...) {
   x$id
 }
@@ -37,6 +46,7 @@ get_fileid <- function(x, ...) {
   UseMethod("get_fileid", x)
 }
 
+#' @export
 get_fileid.numeric <- function(x, file, key = Sys.getenv("DATAVERSE_KEY"), server = Sys.getenv("DATAVERSE_SERVER"), ...) {
   files <- dataset_files(x, key = key, server = server, ...)
   ids <- unlist(lapply(files, function(x) x[["datafile"]][["id"]]))
@@ -57,6 +67,7 @@ get_fileid.numeric <- function(x, file, key = Sys.getenv("DATAVERSE_KEY"), serve
   id
 }
 
+#' @export
 get_fileid.character <- function(x, file, key = Sys.getenv("DATAVERSE_KEY"), server = Sys.getenv("DATAVERSE_SERVER"), ...) {
   files <- dataset_files(prepend_doi(x), key = key, server = server, ...)
   ids <- unlist(lapply(files, function(x) x[["dataFile"]][["id"]]))
@@ -77,6 +88,7 @@ get_fileid.character <- function(x, file, key = Sys.getenv("DATAVERSE_KEY"), ser
   id
 }
 
+#' @export
 get_fileid.dataverse_file <- function(x, ...) {
   x[["dataFile"]][["id"]]
 }
@@ -196,6 +208,37 @@ api_url <- function(server = Sys.getenv("DATAVERSE_SERVER"), prefix = "api/") {
   return(paste0("https://", domain, "/", prefix))
 }
 
+## common httr::GET() uses
+#' @importFrom checkmate assert_string
+api_get <- function(url, ..., key = NULL, as = "text", use_cache = Sys.getenv("DATAVERSE_USE_CACHE", "session")) {
+  assert_string(url)
+  assert_string(key, null.ok = TRUE)
+  assert_string(as, null.ok = TRUE)
+  assert_use_cache(use_cache)
+  get <- switch(
+    use_cache,
+    "none" = api_get_impl,
+    "session" = api_get_session_cache,
+    "disk" = api_get_disk_cache,
+    stop("unknown value for 'use_cache'")
+  )
+  get(url, ..., key = key, as = as)
+}
+
+## cache implemented via memoization; memoized functions defined in
+## .onLoad()
+api_get_impl <- function(url, ..., key = NULL, as = "text") {
+  if (!is.null(key))
+    key <- httr::add_headers("X-Dataverse-key", key)
+  r <- httr::GET(url, ..., key)
+  httr::stop_for_status(r, task = httr::content(r)$message)
+  httr::content(r, as = as, encoding = "UTF-8")
+}
+
+api_get_session_cache <- NULL      # per-session memoisatoin
+
+api_get_disk_cache <- NULL # 'permanent' memoisation
+
 # parse dataset response into list/dataframe
 parse_dataset <- function(out) {
   out <- jsonlite::fromJSON(out)$data
