@@ -22,6 +22,12 @@ test_that("check versions format", {
   ds_index  <- which(sapply(contents, function(x) x$identifier) == "FK2/HXJVJU")
   actual    <- dataset_versions(contents[[ds_index]])
 
-  expect_length(actual[[1]], 17L)
+  expected_names <- c(
+    "citationDate", "createTime", "datasetId", "datasetPersistentId",
+    "fileAccessRequest", "files", "id", "lastUpdateTime", "latestVersionPublishingState",
+    "license", "metadataBlocks", "publicationDate", "releaseTime",
+    "storageIdentifier", "UNF", "versionMinorNumber", "versionNumber",
+    "versionState", "deaccessionLink")
+  expect_setequal(names(actual[[1]]), expected_names)
   expect_s3_class(actual[[2]], "dataverse_dataset_version")
 })
